@@ -231,17 +231,20 @@ class Recipe:
                 return location
 
             os.chdir(location)
-            i, o = os.popen4('svn up')
-            i.close()
+            stdin, stdout, stderr = os.popen3('svn up')
+            stdin.close()
+            for line in stderr.readlines():
+                sys.stderr.write(line)
+            stderr.close()
             change = re.compile('[AUM] ').match
-            for l in o:
+            for l in stdout:
                 if change(l):
-                    o.read()
-                    o.close()
+                    stdout.read()
+                    stdout.close()
                     break
                 else:
                     # No change, so all done
-                    o.close()
+                    stdout.close()
                     return location
 
             assert os.spawnl(
